summaryrefslogtreecommitdiff
path: root/src/test/scala/cookbook
diff options
context:
space:
mode:
authorJack Koenig2018-11-21 14:08:32 -0800
committerJack Koenig2018-12-04 13:13:13 -0800
commit121635ed26c8a9852c827d6c0729515337604d08 (patch)
tree108b4ef217b89cd308ec27ec4e314b400fb369ad /src/test/scala/cookbook
parent277b3979912db443aef4e1aad741ac2b3c07f42f (diff)
Add asBools, deprecate toBools
Diffstat (limited to 'src/test/scala/cookbook')
-rw-r--r--src/test/scala/cookbook/UInt2VecOfBool.scala4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/test/scala/cookbook/UInt2VecOfBool.scala b/src/test/scala/cookbook/UInt2VecOfBool.scala
index f69c483a..10250ad5 100644
--- a/src/test/scala/cookbook/UInt2VecOfBool.scala
+++ b/src/test/scala/cookbook/UInt2VecOfBool.scala
@@ -6,13 +6,13 @@ import chisel3._
/* ### How do I create a Vec of Bools from a UInt?
*
* Use the builtin function [[chisel3.core.Bits.toBools]] to create a Scala Seq of Bool,
* then wrap the resulting Seq in Vec(...)
*/
class UInt2VecOfBool extends CookbookTester(1) {
// Example
val uint = 0xc.U
- val vec = VecInit(uint.toBools)
+ val vec = VecInit(uint.asBools)
printf(p"$vec") // Vec(0, 0, 1, 1)
// Test
@@ -6,13 +6,13 @@ import chisel3._
/* ### How do I create a Vec of Bools from a UInt?
*
- * Use the builtin function [[chisel3.core.Bits.toBools]] to create a Scala Seq of Bool,
+ * Use the builtin function [[chisel3.core.Bits.asBools]] to create a Scala Seq of Bool,
* then wrap the resulting Seq in Vec(...)
*/